@@ -6,7 +6,7 @@ require_once('Net/Sieve.php');
  * Ingo_Driver_timsieved:: Implements the Sieve_Driver api to allow scripts to
  * be installed and set active via a Cyrus timsieved server.
  *
- * $Horde: ingo/lib/Driver/timsieved.php,v 1.15.10.6 2006/01/31 20:00:24 jan Exp $
+ * $Horde: ingo/lib/Driver/timsieved.php,v 1.15.10.7 2006/10/09 15:52:52 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -27,7 +27,8 @@ class Ingo_Driver_timsieved extends Ingo_Driver {
             'logintype'  => 'PLAIN',
             'port'       => 2000,
             'scriptname' => 'ingo',
-            'admin'      => ''
+            'admin'      => '',
+            'usetls'     => true
         );
         $this->_params = array_merge($default_params, $params);
     }
@@ -56,7 +57,10 @@ class Ingo_Driver_timsieved extends Ingo_Driver {
                                 $this->_params['hostspec'],
                                 $this->_params['port'],
                                 $this->_params['logintype'],
-                                $user);
+                                $user,
+                                false,
+                                false,
+                                $this->_params['usetls']);
 
         if (is_a($res = $sieve->getError(), 'PEAR_Error')) {
             return $res;
