@@ -8,7 +8,7 @@ define('INGO_BLACKLIST_MARKER', '++DELETE++');
 /**
  * Ingo base class.
  *
- * $Horde: ingo/lib/Ingo.php,v 1.69.6.15 2006/02/20 21:03:19 jan Exp $
+ * $Horde: ingo/lib/Ingo.php,v 1.69.6.16 2006/10/09 12:58:57 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -248,7 +248,7 @@ class Ingo {
     /**
      * Loads a Ingo_Script:: backend and checks for errors.
      *
-     * @return mixed  Ingo_Script:: object on success, false on failure.
+     * @return Ingo_Script  Script object on success, PEAR_Error on failure.
      */
     function &loadIngoScript()
     {
@@ -257,8 +257,7 @@ class Ingo {
         require_once INGO_BASE . '/lib/Script.php';
         $ingo_script = &Ingo_Script::singleton($_SESSION['ingo']['backend']['script'], isset($_SESSION['ingo']['backend']['scriptparams']) ? $_SESSION['ingo']['backend']['scriptparams'] : array());
         if (is_a($ingo_script, 'PEAR_Error')) {
-            $notification->push($ingo_script->getMessage(), 'horde.error');
-            return false;
+            Horde::fatal($ingo_script, __FILE__, __LINE__);
         }
 
         return $ingo_script;
