@@ -42,7 +42,7 @@ define('INGO_STORAGE_TYPE_BODY', 3);
 /**
  * Ingo_Storage:: defines an API to store the various filter rules.
  *
- * $Horde: ingo/lib/Storage.php,v 1.43.8.15 2006/02/01 18:46:42 jan Exp $
+ * $Horde: ingo/lib/Storage.php,v 1.43.8.16 2006/05/01 13:17:38 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -773,7 +773,7 @@ class Ingo_Storage_filters {
             'conditions' => array(),
             'action' => INGO_STORAGE_ACTION_KEEP,
             'action-value' => '',
-            'stop' => false,
+            'stop' => true,
             'flags' => 0,
             'disable' => false
         );
